@@ -21,11 +21,25 @@ class MobileWorks:
         def get_method( self ):
             return self._method if self._method else urllib2.Request.get_method( self )
     
-    task_url = 'https://work.mobileworks.com/api/v2/task/'
-    job_url = 'https://work.mobileworks.com/api/v2/job/'
-    
     def __init__( self, username, password ):
         self.credentials = base64.encodestring( username + ':' + password )[:-1]
+        self.production()
+        
+    def local(self, port = 8000):
+        self.task_url = 'http://localhost:%d/api/v2/task/' % port
+        self.job_url = 'http://localhost:%d/api/v2/job/' % port
+        
+    def staging(self):
+        task_url = 'https://staging.mobileworks.com/api/v2/task/'
+        job_url = 'https://staging.mobileworks.com/api/v2/job/'
+        
+    def sandbox(self):
+        task_url = 'https://sandbox.mobileworks.com/api/v2/task/'
+        job_url = 'https://sandbox.mobileworks.com/api/v2/job/'
+        
+    def production(self):
+        task_url = 'https://work.mobileworks.com/api/v2/task/'
+        job_url = 'https://work.mobileworks.com/api/v2/job/'
 
     def __make_request( self, url, method = None, post_data = None ):
         """
